@@ -11,6 +11,7 @@ class Alert360Config(AppConfig):
     def ready(self):
         # WARNING: This way the Thread wouldn't run if
         # Statereloader is off
+        print("Alert360 is ready!")
         if os.environ.get('RUN_MAIN') == 'true':
             from .models import StateWatcher
             threading.Thread(
@@ -18,3 +19,6 @@ class Alert360Config(AppConfig):
                 target=StateWatcher.start,
                 daemon=True
             ).start()
+            print("Alert360 Thread started")
+        else:
+            print("Processes dismissed")
