@@ -383,7 +383,9 @@ class StateWatcher(models.Model):
     def start(cls):
         """Start all StateWatchers in Alert360
         """
+        print("Starting Alert360 StatWatchers ")
         for sw in cls.objects.all():
+            print(f"Starting Statewatcher({sw})")
             cls.scheduled_watchers[sw.id] = \
                 {
                     "job": schedule.every(sw.interval).minutes.do(sw.refresh),
